<?php
include 'fns/firewall/load.php';
include 'fns/sql/load.php';
include_once 'fns/SleekDB/Store.php';

$firewall_status = DB::connect()->select('settings', ['value'], ['setting' => 'firewall', 'LIMIT' => 1]);

if (isset($firewall_status[0]) && $firewall_status[0]['value'] !== 'disable') {
    DB::connect()->update('settings', ['value' => 'disable'], ['setting' => 'firewall']);
    cache(['rebuild' => 'settings']);
}

include 'fns/variables/load.php';


if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $output_msg_class = 'success';
    $output_message = 'Completed the selected actions.';


    if (isset($_POST['resetJs'])) {
        $js_files = [
            'assets/js/common/custom_js.js',
            'assets/js/chat_page/custom_js.js',
            'assets/js/entry_page/custom_js.js',
            'assets/js/landing_page/custom_js.js',
        ];


        foreach ($js_files as $js_file) {
            if (file_exists($js_file)) {
                $backup_file = $js_file . '.bak';
                copy($js_file, $backup_file);
                file_put_contents($js_file, '');
            }
        }
        cache(['rebuild' => 'js']);

        foreach ($js_files as $js_file) {
            $backup_file = $js_file . '.bak';
            if (file_exists($backup_file)) {
                $file_content = file_get_contents($backup_file);
                file_put_contents($js_file, $file_content);
                unlink($backup_file);
            }
        }
    }

    if (isset($_POST['resetCss'])) {
        $css_files = [
            'assets/css/common/custom_css.css',
            'assets/css/chat_page/custom_css.css',
            'assets/css/entry_page/custom_css.css',
            'assets/css/landing_page/custom_css.css',
        ];


        foreach ($css_files as $css_file) {
            if (file_exists($css_file)) {
                $backup_file = $css_file . '.bak';
                copy($css_file, $backup_file);
                file_put_contents($css_file, '');
            }
        }
        cache(['rebuild' => 'css']);

        foreach ($css_files as $css_file) {
            $backup_file = $css_file . '.bak';
            if (file_exists($backup_file)) {
                $file_content = file_get_contents($backup_file);
                file_put_contents($css_file, $file_content);
                unlink($backup_file);
            }
        }
    }

    if (isset($_POST['resetHeadersFooters'])) {
        $hf_files = [
            'assets/headers_footers/chat_page/header.php',
            'assets/headers_footers/chat_page/body.php',
            'assets/headers_footers/chat_page/footer.php',
        ];


        foreach ($hf_files as $hf_file) {
            if (file_exists($hf_file)) {
                $backup_file = $hf_file . '.bak';
                copy($hf_file, $backup_file);
                file_put_contents($hf_file, '');
            }
        }
    }

    if (isset($_POST['disableMaintenanceMode'])) {
        DB::connect()->update('settings', ["value" => "disable"], ['setting' => "under_maintenance_mode"]);
        cache(['rebuild' => 'settings']);
    }

    if (isset($_POST['resetCache'])) {
        cache(['rebuild' => 'languages']);
        cache(['rebuild' => 'settings']);
        cache(['rebuild' => 'site_roles']);
        cache(['rebuild' => 'group_roles']);
    }

    if (isset($_POST['forceLogin'])) {

        $admin_email = null;

        if (!empty($_POST['adminEmail'])) {
            $admin_email = $_POST['adminEmail'];
            $admin_site_role = Registry::load('site_role_attributes')->administrators;
            DB::connect()->update('site_users', ["site_role_id" => $admin_site_role], ['email_address' => $admin_email]);
        } else {
            $columns = ['site_users.email_address', 'site_users.user_id'];
            $where = ["site_users.site_role_id" => Registry::load('site_role_attributes')->administrators];
            $where["ORDER"] = ["site_users.user_id" => "ASC"];
            $where["LIMIT"] = 1;
            $admin_account = DB::connect()->select('site_users', $columns, $where);
        }

        if (isset($admin_account[0]) || !empty($admin_email)) {

            if (empty($admin_email) && isset($admin_account[0])) {
                $admin_email = $admin_account[0]['email_address'];
                $user_id = $admin_account[0]['user_id'];
                DB::connect()->delete('login_sessions', ['user_id' => $user_id]);
            }

            include_once('fns/add/load.php');
            $login_session = [
                'add' => 'login_session',
                'user' => $admin_email,
                'return' => true
            ];

            add($login_session, ['force_request' => true]);
            redirect('');
        } else {
            $output_msg_class = 'error';
            $output_message = 'Admin account could not be found. Please enter the email address of the admin account.';
        }

    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Grupo Chat - Troubleshooter</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body, html {
            height: 100%;
            display: flex;
            justify-content: center;
            align-items: center;
            font-family: Arial, sans-serif;
            background-color: #121212;
            color: #e0e0e0;
        }

        .form-container {
            background-color: #1e1e1e;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.5);
            width: 100%;
            max-width: 300px;
            min-width: 300px;
        }

        h2 {
            text-align: center;
            margin-bottom: 10px;
        }

        h2::after {
            content: '';
            display: block;
            width: 60%;
            height: 2px;
            background: #4CAF50;
            margin: 10px auto;
        }

        .form-group {
            display: flex;
            align-items: center;
            margin-bottom: 15px;
            flex-wrap: wrap;
        }

        .form-group input[type="checkbox"] {
            margin-right: 10px;
            width: 20px;
            height: 20px;
        }

        label {
            font-size: 16px;
        }

        .form-group label {
            cursor: pointer;
        }

        input#adminEmail {
            width: 100%;
            padding: 8px;
            margin-top: 8px;
            background-color: #131313;
            color: #e0e0e0;
            border: 0px;
            border: 1px solid #000;
            font-size: 15px;
            border-radius: 9px;
        }

        label.note {
            color: #aaaaaa;
            font-size: 15px;
            line-height: 1.3;
        }

        .submit-btn {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            border: none;
            border-radius: 5px;
            color: #fff;
            font-size: 16px;
            cursor: pointer;
            margin-top: 20px;
        }

        .submit-btn:hover {
            background-color: #45a049;
        }

        .hidden {
            display: none;
        }

        .error-message {
            color: #ff6b6b;
            font-size: 14px;
            margin-bottom: 10px;
            display: none;
        }

        .select-field {
            width: 100%;
            padding: 8px;
            margin-top: 8px;
            border: 1px solid #333;
            border-radius: 4px;
            background-color: #2e2e2e;
            color: #e0e0e0;
        }
        .output_message {
            color: #721c24;
            background-color: #f8d7da;
            border-color: #f5c6cb;
            padding: 5px 10px;
            text-align: center;
            border-radius: 5px;
            margin: 22px 0px;
            font-weight: 500;
            font-size: 16px;
        }

        .output_message.success {
            color: #155724;
            background-color: #d4edda;
            border-color: #c3e6cb;
        }
        .output_message.warning {
            color: #856404;
            background-color: #fff3cd;
            border-color: #ffeeba;
        }
    </style>
</head>
<body>

    <div class="form-container">
        <h2>Troubleshooter</h2>

        <?php if (isset($output_message)) {
            ?>
            <div class="output_message<?php echo ' '.$output_msg_class ?>">
                <?php echo $output_message ?>
            </div>
            <?php
        } ?>

        <form id="resetForm" action="" method="POST">
            <div class="form-group">
                <input type="checkbox" id="resetJs" name="resetJs">
                <label for="resetJs">Reset Custom JS</label>
            </div>
            <div class="form-group">
                <input type="checkbox" id="resetCss" name="resetCss">
                <label for="resetCss">Reset Custom CSS</label>
            </div>
            <div class="form-group">
                <input type="checkbox" id="resetHeadersFooters" name="resetHeadersFooters">
                <label for="resetHeadersFooters">Reset Headers/Footers</label>
            </div>
            <div class="form-group">
                <input type="checkbox" id="disableMaintenanceMode" name="disableMaintenanceMode">
                <label for="disableMaintenanceMode">Disable Maintenance Mode</label>
            </div>
            <div class="form-group">
                <input type="checkbox" id="resetCache" name="resetCache">
                <label for="resetCache">Reset System Cache</label>
            </div>
            <div class="form-group">
                <input type="checkbox" id="forceLogin" name="forceLogin" onclick="toggleAdminField()">
                <label for="forceLogin">Force Login as Admin</label>
            </div>

            <div id="adminEmailField" class="form-group hidden">
                <label for="adminEmail">Admin Email (optional):</label>
                <input type="email" id="adminEmail" name="adminEmail" placeholder="Enter admin email">
            </div>

            <div id="accountIssueField" class="form-group hidden">
                <label for="accountIssue" class="note"><strong>Note : </strong>
                    You don’t need to enter the admin email address, as the system will auto-detect the admin account.
                    Only enter the email if you accidentally changed the role or issued a ban.</label>
            </div>

            <button type="submit" class="submit-btn">Submit</button>

            <div class="output_message warning">
                Be sure to delete the troubleshoot.php file once everything is working smoothly.
            </div>
        </form>

    </div>

    <script>
        function toggleAdminField() {
            const adminEmailField = document.getElementById('adminEmailField');
            const accountIssueField = document.getElementById('accountIssueField');
            const forceLogin = document.getElementById('forceLogin');

            if (forceLogin.checked) {
                adminEmailField.classList.remove('hidden');
                accountIssueField.classList.remove('hidden');
            } else {
                adminEmailField.classList.add('hidden');
                accountIssueField.classList.add('hidden');
            }
        }
    </script>

</body>
</html>